@@ -10,9 +10,9 @@ use Gtk2::GladeXML::OO;
 our $gladexml = Gtk2::GladeXML->new('glade/example.glade');
 $gladexml->signal_autoconnect_from_package('main');
 
-# automatyczna obsluga wywolan standardowych
 sub AUTOLOAD { _autoload_gtk($gladexml, our $AUTOLOAD, @_); }
 
+# see below for code of this class...
 our $myobject = MyObject->new();
 
 #######################################################################
@@ -27,6 +27,7 @@ Gtk2->main;
 #======================================================================
 # Here or in separate file... 
 {
+
 package MyObject;
 
 our $VERSION = '0.01';
@@ -35,8 +36,15 @@ sub new {
 	return bless \$_[0], $_[0]; 
 }
 
-sub set_it { 
-	print "I was clicked!\n"; 
+sub method {
+	my $self = shift;
+
+	if($#_ == -1) {
+		print "Callback without params!\n";
+	} else {
+		print "Parameters: @_\n"; 
+	}
 }
+
 }
 #======================================================================
